@@ -11,7 +11,7 @@ double get_pvalue(double *r, double *ppcc, int *nmc);
 void ppcctest_norm(double *p, double *ppcc, int *n, int *nmc, double *pval)
 {
   double *res; 
-  int i , j, count;
+  int i , j;
   int mc = nmc[0];
   int nn = n[0];
   double *M, *qq, *r;
